@@ -1,4 +1,4 @@
-# $Id: owm.py 1633 2016-12-24 15:04:37Z mwall $
+# $Id: owm.py 1641 2016-12-29 22:12:02Z mwall $
 # Copyright 2013 Matthew Wall
 """
 Upload data to OpenWeatherMap
@@ -34,7 +34,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.5"
+VERSION = "0.6"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -52,6 +52,11 @@ def loginf(msg):
 def logerr(msg):
     logmsg(syslog.LOG_ERR, msg)
 
+
+def _obfuscate(s):
+    return ('X'*(len(s)-4) + s[-4:])
+
+
 class OpenWeatherMap(weewx.restx.StdRESTbase):
     def __init__(self, engine, config_dict):
         """This service recognizes standard restful options plus the following:
@@ -167,7 +172,8 @@ class OpenWeatherMapThread(weewx.restx.RESTThread):
         data = self.get_data(r)
         url = "%s?appid=%s" % (self.server_url, self.appid)
         if weewx.debug > 1:
-            logdbg('url: %s' % self.server_url)
+            logdbg('url: %s?appid=%s' %
+                   (self.server_url, _obfuscate(self.appid)))
             logdbg('data: %s' % data)
         if self.skip_upload:
             loginf("skipping upload")
@@ -189,5 +195,5 @@ class OpenWeatherMapThread(weewx.restx.RESTThread):
             rkey = self._DATA_MAP[_key][0]
             if rkey in record and record[rkey] is not None:
                 values[_key] = record[rkey] * self._DATA_MAP[_key][1] + self._DATA_MAP[_key][2]
-        data = json.dumps(values)
+        data = json.dumps([values])
         return data
